# -*- coding: utf-8 -*-
import os
from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.conf import settings
from cms.models.pluginmodel import CMSPlugin
from jmb.cms.shortcut_icon.models import IconField



class IconSettings(CMSPlugin):
    """
    Shortcut icon plugin
    """
    image = IconField(_("icon"), upload_to=CMSPlugin.get_media_path)
    template_name = models.CharField(max_length=100, choices=settings.SHORTCUT_ICON_CMSPLUGIN_TEMPLATES,
        default="cms_plugins/shortcut_icon.html", editable=len(settings.SHORTCUT_ICON_CMSPLUGIN_TEMPLATES) > 1)

    def file_exists(self):
        return os.path.exists(self.image.path)


    def get_file_name(self):
        return os.path.basename(self.image.path)


    def get_ext(self):
        return os.path.splitext(self.get_file_name())[1][1:].lower()


    def __unicode__(self):
        return self.get_file_name()


    class Meta:
        app_label = "shortcut_icon"
        verbose_name = _("Shortcut Icon")